/*
  COPYRIGHT NOTICE
  Copyright (c) 2012  Scott C. Neu and Arthur W. Toga

  This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package edu.ucla.loni.freesurfer;

/**
 * Metadata for the Free Surfer ASCII Curv Format.
 *
 * @version 29 January 2009
 */
public class AsciiCurvMeta
{
    /** Comment. */
    private String _comment;

    /** Vertex count. */
    private int _vertexCount;

    /**
     * Constructs an ASCII Curv Meta.
     *
     * @param comment Comment.
     * @param vertexCount Vertex count.
     */
    public AsciiCurvMeta(byte[] comment, int vertexCount)
    {
	_comment = _createString(comment);
	_vertexCount = vertexCount;
    }

    /**
     * Gets the comment.
     *
     * @return Comment.
     */
    public String getComment()
    {
	return _comment;
    }

    /**
     * Gets the vertex count.
     *
     * @return Vertex count.
     */
    public int getVertexCount()
    {
	return _vertexCount;
    }

    /**
     * Creates a String from the byte array.
     *
     * @param byteArray Array of bytes to construct a String from.
     *
     * @return String created from the byte array.
     */
    private String _createString(byte[] byteArray)
    {
	// Determine the location of the first null character
	int loc;
	for (loc = 0; loc < byteArray.length && byteArray[loc] != 0; loc++) {}

	// Return a String
	return new String(byteArray, 0, loc);
    }
}
