/*
  COPYRIGHT NOTICE
  Copyright (c) 2012  Scott C. Neu and Arthur W. Toga

  This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package edu.ucla.loni.freesurfer;

/**
 * Metadata for the Free Surfer "New" Curv Format.
 *
 * @version 29 January 2009
 */
public class CurvMeta
{
    /** Vertex count. */
    private int _vertexCount;

    /** Face count. */
    private int _faceCount;

    /** Number of values per vertex. */
    private int _valsPerVertex;

    /**
     * Constructs a Curv Meta.
     *
     * @param vertexCount Vertex count.
     * @param faceCount Face count.
     * @param valsPerVertex Number of values per vertex.
     */
    public CurvMeta(int vertexCount, int faceCount, int valsPerVertex)
    {
	_vertexCount = vertexCount;
	_faceCount = faceCount;
	_valsPerVertex = valsPerVertex;
    }

    /**
     * Gets the vertex count.
     *
     * @return Vertex count.
     */
    public int getVertexCount()
    {
	return _vertexCount;
    }

    /**
     * Get the face count.
     *
     * @return Face count.
     */
    public int getFaceCount()
    {
	return _faceCount;
    }

    /**
     * Gets the number of values per vertex.
     *
     * @return Number of values per vertex.
     */
    public int getValsPerVertex()
    {
	return _valsPerVertex;
    }
}
