/*
  COPYRIGHT NOTICE
  Copyright (c) 2012  Scott C. Neu and Arthur W. Toga

  This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package edu.ucla.loni.freesurfer;

/**
 * Floats found in the MGH header.
 *
 * @version 16 March 2009
 */
public class MghFloat
{
    /** Repetition time (in milliseconds). */
    public static final String TR = "tr";

    /** Flip angle (in radians). */
    public static final String FLIP_ANGLE = "flipAngle";

    /** Echo time (in milliseconds). */
    public static final String TE = "te";

    /** Inversion time (in milliseconds). */
    public static final String TI = "ti";

    /** Field of view. */
    public static final String FOV = "fov";

    /** Float name. */
    private String _name;

    /** Float value. */
    private float _value;

    /**
     * Constructs an MGH Float.
     *
     * @param name Float name.
     * @param value Float value.
     */
    public MghFloat(String name, float value)
    {
	_name = name;
	_value = value;
    }

    /**
     * Gets the float name.
     *
     * @return Name of the float.
     */
    public String getName()
    {
	return _name;
    }

    /**
     * Gets the float value.
     *
     * @return Value of the float.
     */
    public float getValue()
    {
	return _value;
    }
}
