/*
  COPYRIGHT NOTICE
  Copyright (c) 2012  Scott C. Neu and Arthur W. Toga

  This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package edu.ucla.loni.freesurfer;

/**
 * Metadata for the Free Surfer XFM Format.
 *
 * @version 14 January 2010
 */
public class XfmMeta
{
    /** Transform type. */
    private String _transformType;

    /** Comments. */
    private String[] _comments;

    /** Elements of the linear transform. */
    private String[] _transformElems;

    /**
     * Constructs an XFM Meta.
     *
     * @param transformType Transform type.
     * @param comments Comments.
     * @param transformElems Elements of the linear transform.
     *
     * @throws IllegalArgumentException If there are not 12 elements.
     */
    public XfmMeta(String transformType, String[] comments,
		   String[] transformElems)
    {
	// Count the number elements
	if (transformElems.length != 12) {
	    throw new IllegalArgumentException("Not 12 transform elements");
	}

	_transformType = transformType;
	_comments = (String[])comments.clone();
	_transformElems = (String[])transformElems.clone();
    }

    /**
     * Gets the transform type.
     *
     * @return Transform type.
     */
    public String getTransformType()
    {
	return _transformType;
    }

    /**
     * Gets the comments.
     *
     * @return Comments.
     */
    public String[] getComments()
    {
	return (String[])_comments.clone();
    }

    /**
     * Gets the indexed transformation element.
     *
     * @param index Index of the transformation element.
     *
     * @return Indexed transformation element.
     *
     * @throws IndexOutOfBoundsException If the index is invalid.
     */
    public String getTransformElem(int index)
    {
	return _transformElems[index];
    }
}
