/*
  COPYRIGHT NOTICE
  Copyright (c) 2012  Scott C. Neu and Arthur W. Toga

  This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package edu.ucla.loni.freesurfer.plugin;

import java.util.ListResourceBundle;

/**
 * List Resource Bundle that provides descriptions for Free Surfer XFM fields.
 *
 * @version 14 January 2010
 */
public class XfmFormatResources extends ListResourceBundle
{
    /** Constructs an XFM Format Resources. */
    public XfmFormatResources()
    {
    }

    /**
     * Gets the contents of the Resource Bundle.
     *
     * @return Object array of the contents, where each item of the array is a
     *         pair of Objects.  The first element of each pair is the key,
     *         which must be a String, and the second element is the value
     *         associated with that key.
     */
    public Object[][] getContents()
    {
	String rootName = XfmFormat.NATIVE_METADATA_FORMAT_NAME;

	Object[][] contents = {

	    // Node name + "/" + attribute name, followed by description
	    {rootName + "/" + XfmFormat.TRANSFORM_TYPE,
	     "Transform type."},
	    {XfmFormat.COMMENT, "Comment."},
	    {XfmFormat.COMMENT + "/" + XfmFormat.COMMENT_TEXT,
	     "Text of the comment."},
	    {XfmFormat.LINEAR_TRANSFORM, "Linear transform matrix."},
	    {XfmFormat.LINEAR_TRANSFORM + "/" + XfmFormat.ELEM_1_1,
	     "Element (1,1) of the linear transform."},
	    {XfmFormat.LINEAR_TRANSFORM + "/" + XfmFormat.ELEM_1_2,
	     "Element (1,2) of the linear transform."},
	    {XfmFormat.LINEAR_TRANSFORM + "/" + XfmFormat.ELEM_1_3,
	     "Element (1,3) of the linear transform."},
	    {XfmFormat.LINEAR_TRANSFORM + "/" + XfmFormat.ELEM_1_4,
	     "Element (1,4) of the linear transform."},
	    {XfmFormat.LINEAR_TRANSFORM + "/" + XfmFormat.ELEM_2_1,
	     "Element (2,1) of the linear transform."},
	    {XfmFormat.LINEAR_TRANSFORM + "/" + XfmFormat.ELEM_2_2,
	     "Element (2,2) of the linear transform."},
	    {XfmFormat.LINEAR_TRANSFORM + "/" + XfmFormat.ELEM_2_3,
	     "Element (2,3) of the linear transform."},
	    {XfmFormat.LINEAR_TRANSFORM + "/" + XfmFormat.ELEM_2_4,
	     "Element (2,4) of the linear transform."},
	    {XfmFormat.LINEAR_TRANSFORM + "/" + XfmFormat.ELEM_3_1,
	     "Element (3,1) of the linear transform."},
	    {XfmFormat.LINEAR_TRANSFORM + "/" + XfmFormat.ELEM_3_2,
	     "Element (3,2) of the linear transform."},
	    {XfmFormat.LINEAR_TRANSFORM + "/" + XfmFormat.ELEM_3_3,
	     "Element (3,3) of the linear transform."},
	    {XfmFormat.LINEAR_TRANSFORM + "/" + XfmFormat.ELEM_3_4,
	     "Element (3,4) of the linear transform."}
	};

	return contents;
    }
}

