/*
  COPYRIGHT NOTICE
  Copyright (c) 2012  Scott C. Neu and Arthur W. Toga

  This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package edu.ucla.loni.imageio;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;

/**
 * File Image Output Stream that contains a reference to the output file.
 *
 * @version 19 March 2009
 */
public class FileImageOutputStream
       extends javax.imageio.stream.FileImageOutputStream
{
    /** File that is written to. */
    private File _file;

    /**
     * Constructs a File Image Output Stream.
     *
     * @param file File that is written to.
     *
     * @throws FileNotFoundException If the file is a directory or if it cannot
     *                               be opened for reading and writing.
     * @throws IOException If an I/O error occurs.
     * @throws IllegalArgumentException If the file is null.
     */
    public FileImageOutputStream(File file)
	throws FileNotFoundException, IOException
    {
	super(file);

	_file = file;
    }

    /**
     * Gets the file that is written to.
     *
     * @return File that is written to.
     */
    public File getFile()
    {
	return _file;
    }
}
