/*
  COPYRIGHT NOTICE
  Copyright (c) 2012  Scott C. Neu and Arthur W. Toga

  This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package edu.ucla.loni.jdicom.plugin.node;

import edu.ucla.loni.jdicom.plugin.DicomMetadataFormat;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;

/**
 * DICOM Node that represents a data value.
 *
 * @version 2 April 2010
 */
public class ValueNode extends DicomNode
{
    /** Value attribute. */
    private AttributeNode _attribute;

    /**
     * Constructs a Value Node.
     *
     * @param value Value of the Node.
     */
    public ValueNode(Object value)
    {
	// Create the attribute
	_attribute = new AttributeNode(DicomMetadataFormat.VALUE_ATTRIBUTE_NAME,
				       value);
    }

    /**
     * Gets the value.
     *
     * @return value.
     */
    public String getValue()
    {
	return _attribute.getValue();
    }

    /**
     * Gets the Node name.
     *
     * @return Name of the Node.
     */
    public String getNodeName()
    {
	return DicomMetadataFormat.VALUE_NODE_NAME;
    }

    /**
     * Gets the Node type.
     *
     * @return Node type.
     */
    public short getNodeType()
    {
	return ELEMENT_NODE;
    }

    /**
     * Gets the attributes of this Node.
     *
     * @return Attributes of this Node, or null if there are no attributes.
     */
    public NamedNodeMap getAttributes()
    {
	return _attribute;
    }

    /**
     * Gets a duplicate of this Node.  The duplicate Node has no parent.  If a
     * shallow clone is being performed, the duplicate Node will not have any
     * children or siblings.  If a deep clone is performed, the duplicate Node
     * will form the root of a completely cloned subtree.
     *
     * @param deep True for a recursive clone, false for cloning only the Node
     *             itself.
     *
     * @return Duplicate Node.
     */
    public Node cloneNode(boolean deep)
    {
	return new ValueNode( _attribute.getValue() );
    }

    /**
     * Determines if this Node has attributes.
     *
     * @return True if this Node has attributes; false otherwise.
     */
    public boolean hasAttributes()
    {
	return true;
    }
}
