/*
  COPYRIGHT NOTICE
  Copyright (c) 2012  Scott C. Neu and Arthur W. Toga

  This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package edu.ucla.loni.jdicom.plugin.write;

import java.io.IOException;
import java.io.OutputStream;

/**
 * Output stream that counts the number of bytes written to it without actually
 * writing the bytes.
 *
 * @version 16 March 2011
 */
public class CounterOutputStream extends OutputStream
{
    /** Number of bytes written. */
    private long _numberOfBytes;

    /** Constructs a Counter Output Stream. */
    public CounterOutputStream()
    {
    }

    /**
     * Gets the number of bytes written.
     *
     * @return Number of bytes written.
     */
    public long getNumberOfBytesWritten()
    {
	return _numberOfBytes;
    }

    /**
     * Writes the byte.
     *
     * @param b Byte to write.
     *
     * @throws IOException If an I/O error occurs.
     */
    public void write(int b) throws IOException
    {
	_numberOfBytes++;
    }

    /**
     * Writes the specified bytes.
     *
     * @param b Bytes to write.
     * @param off Offset in the byte array to start writing from.
     * @param len Number of bytes to write.
     *
     * @throws IOException If an I/O error occurs.
     */
    public void write(byte b[], int off, int len) throws IOException
    {
	_numberOfBytes += len;
    }
}
