/*
  COPYRIGHT NOTICE
  Copyright (c) 2012  Scott C. Neu and Arthur W. Toga

  This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package edu.ucla.loni.nrrd.plugin;

import edu.ucla.loni.blobio.BlobReader;
import edu.ucla.loni.blobio.spi.BlobReaderSpi;
import java.io.File;
import java.io.IOException;
import java.util.Locale;
import java.util.Vector;
import javax.imageio.stream.ImageInputStream;

/**
 * Blob Reader SPI (Service Provider Interface) for the NRRD image format.
 *
 * @version 2 November 2010
 */
public class NrrdBlobReaderSpi extends BlobReaderSpi
{
    /** Name of the vendor who supplied this plug-in. */
    private static String _vendorName = "Laboratory of Neuro Imaging (LONI)";

    /** Version of this plug-in. */
    private static String _version = "1.0";

    /** Names of the formats read by this plug-in. */
    private static String[] _formatNames = {"nrrd", "NRRD"};

    /** Names of commonly used suffixes for files in the supported formats. */
    private static String[] _fileSuffixes = {"nrrd", "NRRD", "nhdr", "NHDR",
					     "raw", "RAW", "raw.gz", "RAW.GZ"};

    /** MIME types of supported formats. */
    private static String[] _mimeTypes = {"image/nhdr", "image/nrrd"};

    /** Name of the associated Blob Reader. */
    private static String _reader = NrrdBlobReader.class.getName();

    /** Allowed input type classes for the plugin-in. */
    private static Class[] _inputTypes = {NrrdInputStream.class, File.class,
					  ImageInputStream.class, Vector.class};

    /** Names of the associated Blob Writer SPI's. */
    private static String[] _writeSpis =
    {NrrdBlobWriterSpi.class.getName()};

    /** Constructs an NRRD Blob Reader SPI. */
    public NrrdBlobReaderSpi()
    {
	super(_vendorName, _version, _formatNames, _fileSuffixes, _mimeTypes,
	      _reader, _inputTypes, _writeSpis,
	      NrrdMetadataFormat.NATIVE_METADATA_FORMAT_NAME,
	      NrrdMetadataFormat.class.getName());
    }

    /**
     * Determines if the supplied source object appears to be in a supported
     * format.  After the determination is made, the source is reset to its
     * original state if that operation is allowed.
     *
     * @param source Source Object to examine.
     *
     * @return True if the supplied source object appears to be in a supported
     *         format; false otherwise.
     *
     * @throws IOException If an I/O error occurs while reading a stream.
     * @throws IllegalArgumentException If the source is null.
     */
    public boolean canDecodeInput(Object source) throws IOException
    {
	NrrdImageReaderSpi imageReaderSpi = new NrrdImageReaderSpi();
	return imageReaderSpi.canDecodeInput(source);
    }

    /**
     * Returns a brief, human-readable description of this service provider and
     * its associated implementation.
     *
     * @param locale Locale for which the return value should be localized.
     *
     * @return Description of this service provider.
     */
    public String getDescription(Locale locale)
    {
	NrrdImageReaderSpi imageReaderSpi = new NrrdImageReaderSpi();
	return imageReaderSpi.getDescription(locale);
    }

    /**
     * Returns an instance of the Blob Reader implementation associated with
     * this service provider.  The returned object will be in an initial state
     * as if its reset method had been called.
     *
     * @return A Blob Reader instance.
     */
    public BlobReader createReaderInstance()
    {
	return new NrrdBlobReader(this);
    }
}
