/*
COPYRIGHT NOTICE
Copyright (c) 2012  Scott C. Neu, Daniel J. Valentino, and Arthur W. Toga

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package edu.ucla.loni.pacs.plugin;

import edu.ucla.loni.pacs.PacsElements;
import java.util.ListResourceBundle;

/**
 * List Resource Bundle that provides descriptions for UCLA PACS medical image
 * data.
 *
 * @version 5 April 2004
 */
public class PacsMetadataFormatResources extends ListResourceBundle
{
  /** Constructs a PACS Metadata Format Resources. */
  public PacsMetadataFormatResources()
    {
    }

  /**
   * Gets the contents of the Resource Bundle.
   *
   * @return Object array of the contents, where each item of the array is a
   *         pair of Objects.  The first element of each pair is the key, which
   *         must be a String, and the second element is the value associated
   *         with that key.
   */
  public Object[][] getContents()
    {
      String streamName = PacsStreamMetadataFormat.NATIVE_METADATA_FORMAT_NAME;
      String pacsHeader = PacsStreamMetadataFormat.PACS_HEADER_NAME;
      String pacsMrSubheader = PacsStreamMetadataFormat.PACS_MR_SUBHEADER_NAME;
      String pacsCtSubheader = PacsStreamMetadataFormat.PACS_CT_SUBHEADER_NAME;
      String pacsCrSubheader = PacsStreamMetadataFormat.PACS_CR_SUBHEADER_NAME;
      String pacsXaSubheader = PacsStreamMetadataFormat.PACS_XA_SUBHEADER_NAME;
      String imageName = PacsImageMetadataFormat.NATIVE_METADATA_FORMAT_NAME;
      String imgSubheader = PacsImageMetadataFormat.PACS_IMG_SUBHEADER_NAME;
      String imgXSubheader = PacsImageMetadataFormat.PACS_IMGX_SUBHEADER_NAME;

      Object[][] contents = {

	// Node name, followed by description
	{streamName, "UCLA PACS stream metadata."},
	{pacsHeader, "Contains general information."},
	{pacsMrSubheader, "Contains MR-specific data."},
	{pacsCtSubheader, "Contains CT-specific data."},
	{pacsCrSubheader, "Contains CR-specific data."},
	{pacsXaSubheader, "Contains XA-specific data."},
	{imageName, "UCLA PACS image metadata."},
	{imgSubheader, "Contains basic image-specific data."},
	{imgXSubheader, "Contains extra image-specific data."},

	// Node name + "/" + attribute name, followed by description
	{pacsHeader + "/" + PacsElements.FILE_TYPE,
	 PacsElements.FILE_TYPE_DESC},
	{pacsHeader + "/" + PacsElements.IMG_DIM,
	 PacsElements.IMG_DIM_DESC},
	{pacsHeader + "/" + PacsElements.IMG_ROWS,
	 PacsElements.IMG_ROWS_DESC},
	{pacsHeader + "/" + PacsElements.IMG_COLS,
	 PacsElements.IMG_COLS_DESC},
	{pacsHeader + "/" + PacsElements.NO_IMG_IN_FILE,
	 PacsElements.NO_IMG_IN_FILE_DESC},
	{pacsHeader + "/" + PacsElements.PIX_BIT_ALLOCATED,
	 PacsElements.PIX_BIT_ALLOCATED_DESC},
	{pacsHeader + "/" + PacsElements.PIX_BIT_STORED,
	 PacsElements.PIX_BIT_STORED_DESC},
	{pacsHeader + "/" + PacsElements.PIX_BIT_HIGH_POS,
	 PacsElements.PIX_BIT_HIGH_POS_DESC},
	{pacsHeader + "/" + PacsElements.COMPR_FLAG,
	 PacsElements.COMPR_FLAG_DESC},
	{pacsHeader + "/" + PacsElements.COMPR_VERSION,
	 PacsElements.COMPR_VERSION_DESC},
	{pacsHeader + "/" + PacsElements.X_PIX_SIZE,
	 PacsElements.X_PIX_SIZE_DESC},
	{pacsHeader + "/" + PacsElements.Y_PIX_SIZE,
	 PacsElements.Y_PIX_SIZE_DESC},
	{pacsHeader + "/" + PacsElements.STUDY_SLICE_THICKNESS,
	 PacsElements.STUDY_SLICE_THICKNESS_DESC},
	{pacsHeader + "/" + PacsElements.STUDY_SLICE_SPACING,
	 PacsElements.STUDY_SLICE_SPACING_DESC},
	{pacsHeader + "/" + PacsElements.FIELD_OF_VIEW,
	 PacsElements.FIELD_OF_VIEW_DESC},
	{pacsHeader + "/" + PacsElements.SUBHDR_BLK_SIZE,
	 PacsElements.SUBHDR_BLK_SIZE_DESC},
	{pacsHeader + "/" + PacsElements.SUBHDR_BLOCK_POSITION,
	 PacsElements.SUBHDR_BLOCK_POSITION_DESC},
	{pacsHeader + "/" + PacsElements.RID_PATH,
	 PacsElements.RID_PATH_DESC},
	{pacsHeader + "/" + PacsElements.RID_FILENAME,
	 PacsElements.RID_FILENAME_DESC},
	{pacsHeader + "/" + PacsElements.EXAM_REFERENCE_NO,
	 PacsElements.EXAM_REFERENCE_NO_DESC},
	{pacsHeader + "/" + PacsElements.STUDY_REFERENCE_NO,
	 PacsElements.STUDY_REFERENCE_NO_DESC},
	{pacsHeader + "/" + PacsElements.SERIES_REFERENCE_NO,
	 PacsElements.SERIES_REFERENCE_NO_DESC},
	{pacsHeader + "/" + PacsElements.RIS_STUDY_NO,
	 PacsElements.RIS_STUDY_NO_DESC},
	{pacsHeader + "/" + PacsElements.PACS_STUDY_NO,
	 PacsElements.PACS_STUDY_NO_DESC},
	{pacsHeader + "/" + PacsElements.PATIENT_ID,
	 PacsElements.PATIENT_ID_DESC},
	{pacsHeader + "/" + PacsElements.PATIENT_NAME,
	 PacsElements.PATIENT_NAME_DESC},
	{pacsHeader + "/" + PacsElements.PATIENT_BIRTH_DATE,
	 PacsElements.PATIENT_BIRTH_DATE_DESC},
	{pacsHeader + "/" + PacsElements.PAT_SEX,
	 PacsElements.PAT_SEX_DESC},
	{pacsHeader + "/" + PacsElements.PATIENT_HISTORY,
	 PacsElements.PATIENT_HISTORY_DESC},
	{pacsHeader + "/" + PacsElements.PATIENT_STATUS,
	 PacsElements.PATIENT_STATUS_DESC},
	{pacsHeader + "/" + PacsElements.REASON_FOR_REQUEST,
	 PacsElements.REASON_FOR_REQUEST_DESC},
	{pacsHeader + "/" + PacsElements.STUDY_DESCRIPTION,
	 PacsElements.STUDY_DESCRIPTION_DESC},
	{pacsHeader + "/" + PacsElements.STUDY_SUBDESCRIPTION,
	 PacsElements.STUDY_SUBDESCRIPTION_DESC},
	{pacsHeader + "/" + PacsElements.STUDY_ACQ_DATE,
	 PacsElements.STUDY_ACQ_DATE_DESC},
	{pacsHeader + "/" + PacsElements.STUDY_ACQ_TIME,
	 PacsElements.STUDY_ACQ_TIME_DESC},
	{pacsHeader + "/" + PacsElements.STUDY_RADIOLOGIST,
	 PacsElements.STUDY_RADIOLOGIST_DESC},
	{pacsHeader + "/" + PacsElements.STUDY_REF_PHYSICIAN,
	 PacsElements.STUDY_REF_PHYSICIAN_DESC},
	{pacsHeader + "/" + PacsElements.STUDY_MODALITY,
	 PacsElements.STUDY_MODALITY_DESC},
	{pacsHeader + "/" + PacsElements.STUDY_MISC_INFO,
	 PacsElements.STUDY_MISC_INFO_DESC},
	{pacsHeader + "/" + PacsElements.PATIENT_PREPARATION,
	 PacsElements.PATIENT_PREPARATION_DESC},
	{pacsHeader + "/" + PacsElements.INST_STATION_ID,
	 PacsElements.INST_STATION_ID_DESC},
	{pacsHeader + "/" + PacsElements.INST_ACQ_MANUF,
	 PacsElements.INST_ACQ_MANUF_DESC},
	{pacsHeader + "/" + PacsElements.INST_ACQ_MODEL,
	 PacsElements.INST_ACQ_MODEL_DESC},
	{pacsHeader + "/" + PacsElements.INST_ID,
	 PacsElements.INST_ID_DESC},
	{pacsHeader + "/" + PacsElements.RIS_STUDY_NO_EXT,
	 PacsElements.RIS_STUDY_NO_EXT_DESC},
	{pacsHeader + "/" + PacsElements.IMG_ORIG_ID_NO,
	 PacsElements.IMG_ORIG_ID_NO_DESC},
	{pacsHeader + "/" + PacsElements.FREE_TEXT,
	 PacsElements.FREE_TEXT_DESC},

	{pacsMrSubheader + "/" + PacsElements.MR_PAT_ORIENTATION,
	 PacsElements.MR_PAT_ORIENTATION_DESC},
	{pacsMrSubheader + "/" + PacsElements.MR_PLANE_NAME,
	 PacsElements.MR_PLANE_NAME_DESC},
	{pacsMrSubheader + "/" + PacsElements.MR_POSITION,
	 PacsElements.MR_POSITION_DESC},
	{pacsMrSubheader + "/" + PacsElements.MR_LONGIT_REF,
	 PacsElements.MR_LONGIT_REF_DESC},
	{pacsMrSubheader + "/" + PacsElements.MR_VERTIC_REF,
	 PacsElements.MR_VERTIC_REF_DESC},
	{pacsMrSubheader + "/" + PacsElements.MR_START_X,
	 PacsElements.MR_START_X_DESC},
	{pacsMrSubheader + "/" + PacsElements.MR_END_X,
	 PacsElements.MR_END_X_DESC},
	{pacsMrSubheader + "/" + PacsElements.MR_START_Y,
	 PacsElements.MR_START_Y_DESC},
	{pacsMrSubheader + "/" + PacsElements.MR_END_Y,
	 PacsElements.MR_END_Y_DESC},
	{pacsMrSubheader + "/" + PacsElements.MR_START_Z,
	 PacsElements.MR_START_Z_DESC},
	{pacsMrSubheader + "/" + PacsElements.MR_END_Z,
	 PacsElements.MR_END_Z_DESC},
	{pacsMrSubheader + "/" + PacsElements.MR_IMAGE_LOCATION,
	 PacsElements.MR_IMAGE_LOCATION_DESC},
	{pacsMrSubheader + "/" + PacsElements.MR_PULSE_SEQ_NAME,
	 PacsElements.MR_PULSE_SEQ_NAME_DESC},
	{pacsMrSubheader + "/" + PacsElements.MR_GATING_NAME,
	 PacsElements.MR_GATING_NAME_DESC},
	{pacsMrSubheader + "/" + PacsElements.MR_GAUSS,
	 PacsElements.MR_GAUSS_DESC},
	{pacsMrSubheader + "/" + PacsElements.MR_COIL_NAME,
	 PacsElements.MR_COIL_NAME_DESC},
	{pacsMrSubheader + "/" + PacsElements.MR_REPETITION_RECOVERY_TIME,
	 PacsElements.MR_REPETITION_RECOVERY_TIME_DESC},
	{pacsMrSubheader + "/" + PacsElements.MR_SCAN_TIME,
	 PacsElements.MR_SCAN_TIME_DESC},
	{pacsMrSubheader + "/" + PacsElements.MR_ECHO_DELAY,
	 PacsElements.MR_ECHO_DELAY_DESC},
	{pacsMrSubheader + "/" + PacsElements.MR_INVERSION_TIME,
	 PacsElements.MR_INVERSION_TIME_DESC},
	{pacsMrSubheader + "/" + PacsElements.MR_NO_ECHOES,
	 PacsElements.MR_NO_ECHOES_DESC},
	{pacsMrSubheader + "/" + PacsElements.MR_NO_EXCITATIONS,
	 PacsElements.MR_NO_EXCITATIONS_DESC},
	{pacsMrSubheader + "/" + PacsElements.MR_FLIP_ANGLE,
	 PacsElements.MR_FLIP_ANGLE_DESC},
	{pacsMrSubheader + "/" + PacsElements.MR_TRAVERSE_TIME,
	 PacsElements.MR_TRAVERSE_TIME_DESC},
	{pacsMrSubheader + "/" + PacsElements.MR_DFLT_WINDOW,
	 PacsElements.MR_DFLT_WINDOW_DESC},
	{pacsMrSubheader + "/" + PacsElements.MR_DFLT_LEVEL,
	 PacsElements.MR_DFLT_LEVEL_DESC},
	{pacsMrSubheader + "/" + PacsElements.MR_STUDY_MIN,
	 PacsElements.MR_STUDY_MIN_DESC},
	{pacsMrSubheader + "/" + PacsElements.MR_STUDY_MAX,
	 PacsElements.MR_STUDY_MAX_DESC},
	{pacsMrSubheader + "/" + PacsElements.MR_FREE_TEXT,
	 PacsElements.MR_FREE_TEXT_DESC},

	{pacsCtSubheader + "/" + PacsElements.CT_SERIES_NAME,
	 PacsElements.CT_SERIES_NAME_DESC},
	{pacsCtSubheader + "/" + PacsElements.CT_EXPO_TIME,
	 PacsElements.CT_EXPO_TIME_DESC},
	{pacsCtSubheader + "/" + PacsElements.CT_EXPO_RATE,
	 PacsElements.CT_EXPO_RATE_DESC},
	{pacsCtSubheader + "/" + PacsElements.CT_KVP,
	 PacsElements.CT_KVP_DESC},
	{pacsCtSubheader + "/" + PacsElements.CT_SCAN_SEQ,
	 PacsElements.CT_SCAN_SEQ_DESC},
	{pacsCtSubheader + "/" + PacsElements.CT_PAT_ORIENT,
	 PacsElements.CT_PAT_ORIENT_DESC},
	{pacsCtSubheader + "/" + PacsElements.CT_SRC_DET_DIST,
	 PacsElements.CT_SRC_DET_DIST_DESC},
	{pacsCtSubheader + "/" + PacsElements.CT_SRC_PAT_DIST,
	 PacsElements.CT_SRC_PAT_DIST_DESC},
	{pacsCtSubheader + "/" + PacsElements.CT_POSIT_REF,
	 PacsElements.CT_POSIT_REF_DESC},
	{pacsCtSubheader + "/" + PacsElements.CT_SLICE_LOC,
	 PacsElements.CT_SLICE_LOC_DESC},
	{pacsCtSubheader + "/" + PacsElements.CT_RECON_DIAM,
	 PacsElements.CT_RECON_DIAM_DESC},
	{pacsCtSubheader + "/" + PacsElements.CT_CONV_KERN,
	 PacsElements.CT_CONV_KERN_DESC},
	{pacsCtSubheader + "/" + PacsElements.CT_RESCAL_INTER,
	 PacsElements.CT_RESCAL_INTER_DESC},
	{pacsCtSubheader + "/" + PacsElements.CT_RESCAL_SLOPE,
	 PacsElements.CT_RESCAL_SLOPE_DESC},
	{pacsCtSubheader + "/" + PacsElements.CT_GRAY_SCALE,
	 PacsElements.CT_GRAY_SCALE_DESC},
	{pacsCtSubheader + "/" + PacsElements.CT_DFLT_LEVEL,
	 PacsElements.CT_DFLT_LEVEL_DESC},
	{pacsCtSubheader + "/" + PacsElements.CT_DFLT_WINDOW,
	 PacsElements.CT_DFLT_WINDOW_DESC},
	{pacsCtSubheader + "/" + PacsElements.CT_STUDY_MIN,
	 PacsElements.CT_STUDY_MIN_DESC},
	{pacsCtSubheader + "/" + PacsElements.CT_STUDY_MAX,
	 PacsElements.CT_STUDY_MAX_DESC},
	{pacsCtSubheader + "/" + PacsElements.CT_FREE_TEXT,
	 PacsElements.CT_FREE_TEXT_DESC},

	{pacsCrSubheader + "/" + PacsElements.CR_SENSITIVITY,
	 PacsElements.CR_SENSITIVITY_DESC},
	{pacsCrSubheader + "/" + PacsElements.CR_RANGE,
	 PacsElements.CR_RANGE_DESC},
	{pacsCrSubheader + "/" + PacsElements.CR_PRE_SAMPLE_MODE,
	 PacsElements.CR_PRE_SAMPLE_MODE_DESC},
	{pacsCrSubheader + "/" + PacsElements.CR_PREPROC_PARAMETERS,
	 PacsElements.CR_PREPROC_PARAMETERS_DESC},
	{pacsCrSubheader + "/" + PacsElements.CR_DISP_WIN_CENTER,
	 PacsElements.CR_DISP_WIN_CENTER_DESC},
	{pacsCrSubheader + "/" + PacsElements.CR_DISP_WIN_WIDTH,
	 PacsElements.CR_DISP_WIN_WIDTH_DESC},
	{pacsCrSubheader + "/" + PacsElements.CR_STUDY_MIN,
	 PacsElements.CR_STUDY_MIN_DESC},
	{pacsCrSubheader + "/" + PacsElements.CR_STUDY_MAX,
	 PacsElements.CR_STUDY_MAX_DESC},
	{pacsCrSubheader + "/" + PacsElements.CR_FREE_TEXT,
	 PacsElements.CR_FREE_TEXT_DESC},

	{pacsXaSubheader + "/" + PacsElements.XA_IMG_FPS,
	 PacsElements.XA_IMG_FPS_DESC},
	{pacsXaSubheader + "/" + PacsElements.XA_IMG_FPS_VARIABLE,
	 PacsElements.XA_IMG_FPS_VARIABLE_DESC},
	{pacsXaSubheader + "/" + PacsElements.XA_IMG_PLANE_TYPE,
	 PacsElements.XA_IMG_PLANE_TYPE_DESC},
	{pacsXaSubheader + "/" + PacsElements.XA_TABLE_MOTION,
	 PacsElements.XA_TABLE_MOTION_DESC},
	{pacsXaSubheader + "/" + PacsElements.XA_POSITIONER_MOTION,
	 PacsElements.XA_POSITIONER_MOTION_DESC},
	{pacsXaSubheader + "/" + PacsElements.XA_PRIM_ANGLE,
	 PacsElements.XA_PRIM_ANGLE_DESC},
	{pacsXaSubheader + "/" + PacsElements.XA_SEC_ANGLE,
	 PacsElements.XA_SEC_ANGLE_DESC},
	{pacsXaSubheader + "/" + PacsElements.XA_FOV_SHAPE,
	 PacsElements.XA_FOV_SHAPE_DESC},
	{pacsXaSubheader + "/" + PacsElements.XA_SOURCE_TO_PATIENT,
	 PacsElements.XA_SOURCE_TO_PATIENT_DESC},
	{pacsXaSubheader + "/" + PacsElements.XA_SOURCE_TO_DETECTOR,
	 PacsElements.XA_SOURCE_TO_DETECTOR_DESC},
	{pacsXaSubheader + "/" + PacsElements.XA_EXPO_KVP,
	 PacsElements.XA_EXPO_KVP_DESC},
	{pacsXaSubheader + "/" + PacsElements.XA_EXPO_CURRENT,
	 PacsElements.XA_EXPO_CURRENT_DESC},
	{pacsXaSubheader + "/" + PacsElements.XA_EXPO_TIME,
	 PacsElements.XA_EXPO_TIME_DESC},
	{pacsXaSubheader + "/" + PacsElements.XA_EXPO_RATE,
	 PacsElements.XA_EXPO_RATE_DESC},
	{pacsXaSubheader + "/" + PacsElements.XA_FOCAL_SPOT,
	 PacsElements.XA_FOCAL_SPOT_DESC},
	{pacsXaSubheader + "/" + PacsElements.XA_CUT_FLAG,
	 PacsElements.XA_CUT_FLAG_DESC},
	{pacsXaSubheader + "/" + PacsElements.XA_NUM_CURVES_ENCLOSED,
	 PacsElements.XA_NUM_CURVES_ENCLOSED_DESC},
	{pacsXaSubheader + "/" + PacsElements.XA_FREE_TEXT,
	 PacsElements.XA_FREE_TEXT_DESC},

	{imgSubheader + "/" + PacsElements.IMG_NUMBER,
	 PacsElements.IMG_NUMBER_DESC},
	{imgSubheader + "/" + PacsElements.IMG_ROWS,
	 PacsElements.IMG_ROWS_DESC},
	{imgSubheader + "/" + PacsElements.IMG_COLS,
	 PacsElements.IMG_COLS_DESC},
	{imgSubheader + "/" + PacsElements.X_PIX_SIZE,
	 PacsElements.X_PIX_SIZE_DESC},
	{imgSubheader + "/" + PacsElements.Y_PIX_SIZE,
	 PacsElements.Y_PIX_SIZE_DESC},
	{imgSubheader + "/" + PacsElements.FIELD_OF_VIEW,
	 PacsElements.FIELD_OF_VIEW_DESC},
	{imgSubheader + "/" + PacsElements.IMG_MIN,
	 PacsElements.IMG_MIN_DESC},
	{imgSubheader + "/" + PacsElements.IMG_MAX,
	 PacsElements.IMG_MAX_DESC},
	{imgSubheader + "/" + PacsElements.RECON_ALGORITHM,
	 PacsElements.RECON_ALGORITHM_DESC},
	{imgSubheader + "/" + PacsElements.THICK,
	 PacsElements.THICK_DESC},

	{imgXSubheader + "/" + PacsElements.VERSION,
	 PacsElements.VERSION_DESC},
	{imgXSubheader + "/" + PacsElements.WINDOW_LEVEL,
	 PacsElements.WINDOW_LEVEL_DESC},
	{imgXSubheader + "/" + PacsElements.WINDOW_WIDTH,
	 PacsElements.WINDOW_WIDTH_DESC},
	{imgXSubheader + "/" + PacsElements.MR_REPETITION_TIME,
	 PacsElements.MR_REPETITION_TIME_DESC},
	{imgXSubheader + "/" + PacsElements.MR_ECHO_TIME,
	 PacsElements.MR_ECHO_TIME_DESC},
	{imgXSubheader + "/" + PacsElements.PAT_ORIENTATION,
	 PacsElements.PAT_ORIENTATION_DESC},
	{imgXSubheader + "/" + PacsElements.IMG_NUMBER,
	 PacsElements.IMG_NUMBER_DESC},
	{imgXSubheader + "/" + PacsElements.IMG_ROWS,
	 PacsElements.IMG_ROWS_DESC},
	{imgXSubheader + "/" + PacsElements.IMG_COLS,
	 PacsElements.IMG_COLS_DESC},
	{imgXSubheader + "/" + PacsElements.X_PIX_SIZE,
	 PacsElements.X_PIX_SIZE_DESC},
	{imgXSubheader + "/" + PacsElements.Y_PIX_SIZE,
	 PacsElements.Y_PIX_SIZE_DESC},
	{imgXSubheader + "/" + PacsElements.FIELD_OF_VIEW,
	 PacsElements.FIELD_OF_VIEW_DESC},
	{imgXSubheader + "/" + PacsElements.IMG_MIN,
	 PacsElements.IMG_MIN_DESC},
	{imgXSubheader + "/" + PacsElements.IMG_MAX,
	 PacsElements.IMG_MAX_DESC},
	{imgXSubheader + "/" + PacsElements.RECON_ALGORITHM,
	 PacsElements.RECON_ALGORITHM_DESC},
	{imgXSubheader + "/" + PacsElements.THICK,
	 PacsElements.THICK_DESC},
	{imgXSubheader + "/" + PacsElements.IMG_POS_PAT_X,
	 PacsElements.IMG_POS_PAT_X_DESC},
	{imgXSubheader + "/" + PacsElements.IMG_POS_PAT_Y,
	 PacsElements.IMG_POS_PAT_Y_DESC},
	{imgXSubheader + "/" + PacsElements.IMG_POS_PAT_Z,
	 PacsElements.IMG_POS_PAT_Z_DESC},
	{imgXSubheader + "/" + PacsElements.PAT_ORIENTATION_X1,
	 PacsElements.PAT_ORIENTATION_X1_DESC},
	{imgXSubheader + "/" + PacsElements.PAT_ORIENTATION_Y1,
	 PacsElements.PAT_ORIENTATION_Y1_DESC},
	{imgXSubheader + "/" + PacsElements.PAT_ORIENTATION_Z1,
	 PacsElements.PAT_ORIENTATION_Z1_DESC},
	{imgXSubheader + "/" + PacsElements.PAT_ORIENTATION_X2,
	 PacsElements.PAT_ORIENTATION_X2_DESC},
	{imgXSubheader + "/" + PacsElements.PAT_ORIENTATION_Y2,
	 PacsElements.PAT_ORIENTATION_Y2_DESC},
	{imgXSubheader + "/" + PacsElements.PAT_ORIENTATION_Z2,
	 PacsElements.PAT_ORIENTATION_Z2_DESC},
	{imgXSubheader + "/" + PacsElements.XA_FRAME_NUMBER,
	 PacsElements.XA_FRAME_NUMBER_DESC},
	{imgXSubheader + "/" + PacsElements.XA_ORIG_FRAME_NO,
	 PacsElements.XA_ORIG_FRAME_NO_DESC},
	{imgXSubheader + "/" + PacsElements.XA_FRAME_INTERVAL,
	 PacsElements.XA_FRAME_INTERVAL_DESC},
	{imgXSubheader + "/" + PacsElements.XA_PRIM_ANGLE_INCREMENT,
	 PacsElements.XA_PRIM_ANGLE_INCREMENT_DESC},
	{imgXSubheader + "/" + PacsElements.XA_SEC_ANGLE_INCREMENT,
	 PacsElements.XA_SEC_ANGLE_INCREMENT_DESC},
	{imgXSubheader + "/" + PacsElements.XA_CURRENT_PRIM_ANGLE,
	 PacsElements.XA_CURRENT_PRIM_ANGLE_DESC},
	{imgXSubheader + "/" + PacsElements.XA_CURRENT_SEC_ANGLE,
	 PacsElements.XA_CURRENT_SEC_ANGLE_DESC},
	{imgXSubheader + "/" + PacsElements.XA_TABLE_VERTIC_INCREMENT,
	 PacsElements.XA_TABLE_VERTIC_INCREMENT_DESC},
	{imgXSubheader + "/" + PacsElements.XA_TABLE_LATERAL_INCREMENT,
	 PacsElements.XA_TABLE_LATERAL_INCREMENT_DESC},
	{imgXSubheader + "/" + PacsElements.XA_TABLE_LONGIT_INCREMENT,
	 PacsElements.XA_TABLE_LONGIT_INCREMENT_DESC}
      };

      return contents;
    }
}
